#include "ytv.h"
#include "ytvprivate.h"



Ytv::Ytv(QObject *parent) :
        QObject( parent ), p(new ytvPrivate(this))
{
    connect(p,SIGNAL(done()), this, SIGNAL(done()));

    connect( p, SIGNAL(error(int)), this, SIGNAL(error(int)));

}


Ytv::~Ytv() {

}

bool Ytv::search(const QString &what) {

    return p->search(what);

}

Location::List Ytv::searchResults() {


    return p->searchResults();
}


bool Ytv::reverseGeoCode(const float x, const float y) {

    Q_UNUSED(x);
    Q_UNUSED(y);

    return true;

}

bool Ytv::route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime, int connectionTime) {

    return p->route(start, dest, datetime, connectionTime);

}

Route::List Ytv::routeResults() {

    return p->routeResults();
}
